@@ -16,7 +16,7 @@ logging.basicConfig(
     datefmt='%Y-%m-%d %H:%M:%S'
 )
 
-def main():
+def service():
     genius_config = get_axya_config()
 
     if genius_config.fetch_sent_purchase_orders_enabled:
@@ -25,4 +25,4 @@ def main():
         get_update_purchase_orders()
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    service()
\ No newline at end of file
