@@ -23,11 +23,14 @@ class HelloWindowService(win32serviceutil.ServiceFramework):
         win32serviceutil.ServiceFramework.__init__(self, args)
         self.hWaitStop = win32event.CreateEvent(None, 0, 0, None)
         self.icon = None
+        self.is_alive = True
+
         socket.setdefaulttimeout(5)
 
     def SvcStop(self):
         self.ReportServiceStatus(win32service.SERVICE_STOP_PENDING)
         win32event.SetEvent(self.hWaitStop)
+        self.is_alive = True
         if self.icon:
             self.icon.stop()
 
@@ -46,24 +49,19 @@ class HelloWindowService(win32serviceutil.ServiceFramework):
 
     def on_exit(self, icon, item):
         self.SvcStop()
-
-
-    def start(self):
-        self.isrunning = True
-
-    def stop(self):
-        self.isrunning = False
         
     def run_service(self):
         self.icon = self.create_system_tray_icon()
 
-        while self.isrunning:
+        while self.is_alive:
             try:
                 service()
-                time.sleep(60)
+                # Sleep for the specified interval
+                if win32event.WaitForSingleObject(self.hWaitStop, 60 * 1000) == win32event.WAIT_OBJECT_0:
+                   # Stop signal received
+                   break
             except Exception as e:
                 servicemanager.LogErrorMsg(str(e))
-                time.sleep(300)
 
 if __name__ == '__main__':
     # Use this block for testing the service as a standalone script
